@@ -1,7 +1,7 @@
 \unset ECHO
 \i test_setup.sql
 
-SELECT plan(280);
+SELECT plan(399);
 --SELECT * FROM no_plan();
 
 -- This will be rolled back. :-)
@@ -47,14 +47,21 @@ CREATE OR REPLACE FUNCTION public.goofy_eq (goofy, goofy) RETURNS boolean AS $$
     SELECT $1 = $2;
 $$ LANGUAGE SQL IMMUTABLE STRICT;
 
-CREATE OPERATOR public.= ( PROCEDURE = goofy_eq, LEFTARG = goofy, RIGHTARG = goofy);
+CREATE SCHEMA disney;
 
-CREATE OPERATOR CLASS public.goofy_ops
+CREATE OPERATOR disney.= ( PROCEDURE = goofy_eq, LEFTARG = goofy, RIGHTARG = goofy);
+
+CREATE OPERATOR CLASS goofy_ops
 DEFAULT FOR TYPE goofy USING BTREE AS
-	OPERATOR 1 =,
+	OPERATOR 1 disney.=,
 	FUNCTION 1 goofy_cmp(goofy,goofy)
 ;
 
+CREATE TYPE someschema.sometype AS (
+    id    INT,
+    name  TEXT
+);
+
 RESET client_min_messages;
 
 /****************************************************************************/
@@ -71,7 +78,7 @@ $$ LANGUAGE SQL;
 SELECT * FROM check_test(
     tablespaces_are( ___myts(''), 'whatever' ),
     true,
-    'tablespaces_are(schemas, desc)',
+    'tablespaces_are(tablespaces, desc)',
     'whatever',
     ''
 );
@@ -79,7 +86,7 @@ SELECT * FROM check_test(
 SELECT * FROM check_test(
     tablespaces_are( ___myts('') ),
     true,
-    'tablespaces_are(schemas)',
+    'tablespaces_are(tablespaces)',
     'There should be the correct tablespaces',
     ''
 );
@@ -87,7 +94,7 @@ SELECT * FROM check_test(
 SELECT * FROM check_test(
     tablespaces_are( array_append(___myts(''), '__booya__'), 'whatever' ),
     false,
-    'tablespaces_are(schemas, desc) missing',
+    'tablespaces_are(tablespaces, desc) missing',
     'whatever',
     '    Missing tablespaces:
         __booya__'
@@ -96,7 +103,7 @@ SELECT * FROM check_test(
 SELECT * FROM check_test(
     tablespaces_are( ___myts('pg_default'), 'whatever' ),
     false,
-    'tablespaces_are(schemas, desc) extra',
+    'tablespaces_are(tablespaces, desc) extra',
     'whatever',
     '    Extra tablespaces:
         pg_default'
@@ -105,7 +112,7 @@ SELECT * FROM check_test(
 SELECT * FROM check_test(
     tablespaces_are( array_append(___myts('pg_default'), '__booya__'), 'whatever' ),
     false,
-    'tablespaces_are(schemas, desc) extras and missing',
+    'tablespaces_are(tablespaces, desc) extras and missing',
     'whatever',
     '    Extra tablespaces:
         pg_default
@@ -520,7 +527,7 @@ CREATE FUNCTION ___myfunk(ex text) RETURNS NAME[] AS $$
           FROM pg_catalog.pg_namespace n
           JOIN pg_catalog.pg_proc p ON n.oid = p.pronamespace
          WHERE pg_catalog.pg_function_is_visible(p.oid)
-           AND n.nspname <> 'pg_catalog'
+           AND n.nspname NOT IN ('pg_catalog', 'information_schema')
            AND p.proname <> $1
     );
 $$ LANGUAGE SQL;
@@ -1008,6 +1015,442 @@ SELECT * FROM check_test(
         del_me'
 );
 
+/****************************************************************************/
+-- Test types_are().
+
+SELECT * FROM check_test(
+    types_are( 'someschema', ARRAY['sometype'], 'whatever' ),
+    true,
+    'types_are(schema, types, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    types_are( 'someschema', ARRAY['sometype'] ),
+    true,
+    'types_are(schema, types)',
+    'Schema someschema should have the correct types'
+    ''
+);
+
+SELECT * FROM check_test(
+    types_are( 'someschema', ARRAY['sometype', 'typo'], 'whatever' ),
+    false,
+    'types_are(schema, types, desc) + missing',
+    'whatever',
+    '    Missing types:
+        typo'
+);
+
+SELECT * FROM check_test(
+    types_are( 'someschema', '{}'::name[], 'whatever' ),
+    false,
+    'types_are(schema, types, desc) + extra',
+    'whatever',
+    '    Extra types:
+        sometype'
+);
+
+SELECT * FROM check_test(
+    types_are( 'someschema', ARRAY['typo'], 'whatever' ),
+    false,
+    'types_are(schema, types, desc) + extra & missing',
+    'whatever',
+    '    Extra types:
+        sometype
+    Missing types:
+        typo'
+);
+
+CREATE FUNCTION ___mytype(ex text) RETURNS NAME[] AS $$
+    SELECT COALESCE(ARRAY(
+            SELECT t.typname
+              FROM pg_catalog.pg_type t
+              LEFT JOIN pg_catalog.pg_namespace n ON n.oid = t.typnamespace
+             WHERE (
+                     t.typrelid = 0
+                 OR (SELECT c.relkind = 'c' FROM pg_catalog.pg_class c WHERE c.oid = t.typrelid)
+             )
+               AND NOT EXISTS(SELECT 1 FROM pg_catalog.pg_type el WHERE el.oid = t.typelem)
+               AND n.nspname NOT IN('pg_catalog', 'information_schema')
+           AND t.typname <> $1
+           AND pg_catalog.pg_type_is_visible(t.oid)
+    ), '{}'::name[]);;
+$$ LANGUAGE SQL;
+
+SELECT * FROM check_test(
+    types_are( ___mytype('') ),
+    true,
+    'types_are(types)',
+    'Search path ' || pg_catalog.current_setting('search_path') || ' should have the correct types',
+    ''
+);
+
+SELECT * FROM check_test(
+    types_are( array_append(___mytype(''), 'silltypo'), 'whatever' ),
+    false,
+    'types_are(types, desc) + missing',
+    'whatever',
+    '    Missing types:
+        silltypo'
+);
+
+SELECT * FROM check_test(
+    types_are( ___mytype('goofy'), 'whatever' ),
+    false,
+    'types_are(types, desc) + extra',
+    'whatever',
+    '    Extra types:
+        goofy'
+);
+
+SELECT * FROM check_test(
+    types_are( array_append(___mytype('goofy'), 'silltypo'), 'whatever' ),
+    false,
+    'types_are(types, desc) + extra & missing',
+    'whatever',
+    '    Extra types:
+        goofy
+    Missing types:
+        silltypo'
+);
+
+/****************************************************************************/
+-- Test domains_are().
+
+SELECT * FROM check_test(
+    domains_are( 'public', ARRAY['goofy'], 'whatever' ),
+    true,
+    'domains_are(schema, domains, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domains_are( 'public', ARRAY['goofy'] ),
+    true,
+    'domains_are(schema, domains)',
+    'Schema public should have the correct domains',
+    ''
+);
+
+SELECT * FROM check_test(
+    domains_are( 'public', ARRAY['freddy'], 'whatever' ),
+    false,
+    'domains_are(schema, domains, desc) fail',
+    'whatever',
+    '    Extra types:
+        goofy
+    Missing types:
+        freddy'
+);
+
+SELECT * FROM check_test(
+    domains_are( 'public', ARRAY['freddy'] ),
+    false,
+    'domains_are(schema, domains) fail',
+    'Schema public should have the correct domains',
+    '    Extra types:
+        goofy
+    Missing types:
+        freddy'
+);
+
+CREATE FUNCTION ___mydo(ex text) RETURNS NAME[] AS $$
+    SELECT COALESCE(ARRAY(
+            SELECT t.typname
+              FROM pg_catalog.pg_type t
+              LEFT JOIN pg_catalog.pg_namespace n ON n.oid = t.typnamespace
+             WHERE (
+                     t.typrelid = 0
+                 OR (SELECT c.relkind = 'c' FROM pg_catalog.pg_class c WHERE c.oid = t.typrelid)
+             )
+               AND NOT EXISTS(SELECT 1 FROM pg_catalog.pg_type el WHERE el.oid = t.typelem)
+               AND n.nspname NOT IN('pg_catalog', 'information_schema')
+           AND t.typname <> $1
+           AND pg_catalog.pg_type_is_visible(t.oid)
+           AND t.typtype = 'd'
+    ), '{}'::name[]);
+$$ LANGUAGE SQL;
+
+SELECT * FROM check_test(
+    domains_are( ___mydo(''), 'whatever' ),
+    true,
+    'domains_are(domains, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domains_are( ___mydo('') ),
+    true,
+    'domains_are(domains)',
+    'Search path ' || pg_catalog.current_setting('search_path') || ' should have the correct domains',
+    ''
+);
+
+SELECT * FROM check_test(
+    domains_are( array_append(___mydo('goofy'), 'fredy'), 'whatever' ),
+    false,
+    'domains_are(domains, desc) fail',
+    'whatever',
+    '    Extra types:
+        goofy
+    Missing types:
+        fredy'
+);
+
+SELECT * FROM check_test(
+    domains_are( array_append(___mydo('goofy'), 'fredy') ),
+    false,
+    'domains_are(domains) fail',
+    'Search path ' || pg_catalog.current_setting('search_path') || ' should have the correct domains',
+    '    Extra types:
+        goofy
+    Missing types:
+        fredy'
+);
+
+/****************************************************************************/
+-- Test casts_are().
+
+CREATE OR REPLACE FUNCTION ___mycasts(ex text) RETURNS TEXT[] AS $$
+    SELECT ARRAY(
+        SELECT display_type(castsource, NULL) || ' AS ' || display_type(casttarget, NULL)
+          FROM pg_catalog.pg_cast
+         WHERE castsource::regtype::text <> $1
+    );
+$$ LANGUAGE SQL;
+
+SELECT * FROM check_test(
+    casts_are( ___mycasts(''), 'whatever' ),
+    true,
+    'casts_are(casts, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    casts_are( ___mycasts('') ),
+    true,
+    'casts_are(casts)',
+    'There should be the correct casts',
+    ''
+);
+
+SELECT * FROM check_test(
+    casts_are( array_append(___mycasts(''), '__booya__ AS integer'), 'whatever' ),
+    false,
+    'casts_are(casts, desc) missing',
+    'whatever',
+    '    Missing casts:
+        __booya__ AS integer'
+);
+
+SELECT * FROM check_test(
+    casts_are( ___mycasts('lseg'), 'whatever' ),
+    false,
+    'casts_are(casts, desc) extra',
+    'whatever',
+    '    Extra casts:
+        lseg AS point'
+);
+
+SELECT * FROM check_test(
+    casts_are( array_append(___mycasts('lseg'), '__booya__ AS integer'), 'whatever' ),
+    false,
+    'casts_are(casts, desc) extras and missing',
+    'whatever',
+    '    Extra casts:
+        lseg AS point
+    Missing casts:
+        __booya__ AS integer'
+);
+
+/****************************************************************************/
+-- Test operators_are().
+SET search_path = disney,public,pg_catalog;
+
+SELECT * FROM check_test(
+    operators_are( 'disney', ARRAY['=(goofy,goofy) RETURNS boolean'], 'whatever' ),
+    true,
+    'operators_are(schema, operators, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    operators_are( 'disney', ARRAY['=(goofy,goofy) RETURNS boolean'] ),
+    true,
+    'operators_are(schema, operators)',
+    'Schema disney should have the correct operators',
+    ''
+);
+
+SELECT * FROM check_test(
+    operators_are( 'disney', ARRAY['+(freddy,freddy) RETURNS barnie'], 'whatever' ),
+    false,
+    'operators_are(schema, operators, desc) fail',
+    'whatever',
+    '    Extra operators:
+        =(goofy,goofy) RETURNS boolean
+    Missing operators:
+        +(freddy,freddy) RETURNS barnie'
+);
+
+SELECT * FROM check_test(
+    operators_are( 'disney', ARRAY['+(freddy,freddy) RETURNS barnie'] ),
+    false,
+    'operators_are(schema, operators) fail',
+    'Schema disney should have the correct operators',
+    '    Extra operators:
+        =(goofy,goofy) RETURNS boolean
+    Missing operators:
+        +(freddy,freddy) RETURNS barnie'
+);
+
+CREATE OR REPLACE FUNCTION ___myops(ex text) RETURNS TEXT[] AS $$
+    SELECT ARRAY(
+        SELECT textin(regoperatorout(o.oid::regoperator)) || ' RETURNS ' || o.oprresult::regtype::text
+          FROM pg_catalog.pg_operator o
+          JOIN pg_catalog.pg_namespace n ON o.oprnamespace = n.oid
+         WHERE pg_catalog.pg_operator_is_visible(o.oid)
+           AND o.oprleft::regtype::text <> $1
+           AND n.nspname NOT IN ('pg_catalog', 'information_schema')
+    );
+$$ LANGUAGE SQL;
+
+SELECT * FROM check_test(
+    operators_are( array_append( ___myops(''), '=(goofy,goofy) RETURNS boolean' ), 'whatever' ),
+    true,
+    'operators_are(operators, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    operators_are( array_append( ___myops(''), '=(goofy,goofy) RETURNS boolean' ) ),
+    true,
+    'operators_are(operators)',
+    'There should be the correct operators',
+    ''
+);
+
+SELECT * FROM check_test(
+    operators_are( array_append( ___myops('goofy'), '+(freddy,freddy) RETURNS barnie' ), 'whatever' ),
+    false,
+    'operators_are(operators, desc) fail',
+    'whatever',
+    '    Extra operators:
+        =(goofy,goofy) RETURNS boolean
+    Missing operators:
+        +(freddy,freddy) RETURNS barnie'
+);
+
+SELECT * FROM check_test(
+    operators_are( array_append( ___myops('goofy'), '+(freddy,freddy) RETURNS barnie' ) ),
+    false,
+    'operators_are(operators) fail',
+    'There should be the correct operators',
+    '    Extra operators:
+        =(goofy,goofy) RETURNS boolean
+    Missing operators:
+        +(freddy,freddy) RETURNS barnie'
+);
+
+/****************************************************************************/
+-- Test columns_are().
+SELECT * FROM check_test(
+    columns_are( 'public', 'fou', ARRAY['id', 'name', 'numb', 'myint'], 'whatever' ),
+    true,
+    'columns_are(schema, table, columns, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    columns_are( 'public', 'fou', ARRAY['id', 'name', 'numb', 'myint'] ),
+    true,
+    'columns_are(schema, table, columns)',
+    'Table public.fou should have the correct columns',
+    ''
+);
+
+SELECT * FROM check_test(
+    columns_are( 'public', 'fou', ARRAY['id', 'name', 'numb'] ),
+    false,
+    'columns_are(schema, table, columns) + extra',
+    'Table public.fou should have the correct columns',
+    '    Extra columns:
+        myint'
+);
+
+SELECT * FROM check_test(
+    columns_are( 'public', 'fou', ARRAY['id', 'name', 'numb', 'myint', 'howdy'] ),
+    false,
+    'columns_are(schema, table, columns) + missing',
+    'Table public.fou should have the correct columns',
+    '    Missing columns:
+        howdy'
+);
+
+SELECT * FROM check_test(
+    columns_are( 'public', 'fou', ARRAY['id', 'name', 'numb', 'howdy'] ),
+    false,
+    'columns_are(schema, table, columns) + extra & missing',
+    'Table public.fou should have the correct columns',
+    '    Extra columns:
+        myint
+    Missing columns:
+        howdy'
+);
+
+SELECT * FROM check_test(
+    columns_are( 'fou', ARRAY['id', 'name', 'numb', 'myint'], 'whatever' ),
+    true,
+    'columns_are(table, columns, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    columns_are( 'fou', ARRAY['id', 'name', 'numb', 'myint'] ),
+    true,
+    'columns_are(table, columns)',
+    'Table fou should have the correct columns',
+    ''
+);
+
+SELECT * FROM check_test(
+    columns_are( 'fou', ARRAY['id', 'name', 'numb'] ),
+    false,
+    'columns_are(table, columns) + extra',
+    'Table fou should have the correct columns',
+    '    Extra columns:
+        myint'
+);
+
+SELECT * FROM check_test(
+    columns_are( 'fou', ARRAY['id', 'name', 'numb', 'myint', 'howdy'] ),
+    false,
+    'columns_are(table, columns) + missing',
+    'Table fou should have the correct columns',
+    '    Missing columns:
+        howdy'
+);
+
+SELECT * FROM check_test(
+    columns_are( 'fou', ARRAY['id', 'name', 'numb', 'howdy'] ),
+    false,
+    'columns_are(table, columns) + extra & missing',
+    'Table fou should have the correct columns',
+    '    Extra columns:
+        myint
+    Missing columns:
+        howdy'
+);
+
 /****************************************************************************/
 -- Finish the tests and clean up.
 SELECT * FROM finish();
